@@ -145,7 +145,7 @@ canl_ctx_set_cred(canl_ctx ctx, canl_cred cred)
 
 void pkey_dup(EVP_PKEY **to, EVP_PKEY *from)
 {
-    CRYPTO_add(&from->references,1,CRYPTO_LOCK_EVP_PKEY);
+    EVP_PKEY_up_ref(from);
     *to = from;
 }
 
@@ -846,6 +846,7 @@ canl_err_code CANL_CALLCONV
 canl_cred_load_priv_key_pkcs11(canl_ctx ctx, canl_cred cred, const char *label,
 			       canl_password_callback pass_clb, void *arg)
 {
+#ifdef USE_PKCS11
     int ret;
     creds *crd = (creds*) cred;
     unsigned long hSession;
@@ -860,11 +861,15 @@ canl_cred_load_priv_key_pkcs11(canl_ctx ctx, canl_cred cred, const char *label,
 			 label);
 
     return 0;
+#else
+    return ENOSYS;
+#endif /* USE_PKCS11 */
 }
 
 canl_err_code CANL_CALLCONV
 canl_cred_load_cert_pkcs11(canl_ctx ctx, canl_cred cred, const char *label)
 {
+#ifdef USE_PKCS11
     int ret;
     creds *crd = (creds*) cred;
     unsigned long hSession;
@@ -879,4 +884,7 @@ canl_cred_load_cert_pkcs11(canl_ctx ctx, canl_cred cred, const char *label)
 			 label);
 
     return 0;
+#else
+    return ENOSYS;
+#endif /* USE_PKCS11 */
 }
