@@ -4,8 +4,8 @@
 #include <openssl/ocsp.h>
 #include <pthread.h>
 
-#define SSL_SERVER_METH SSLv23_server_method()
-#define SSL_CLIENT_METH SSLv3_client_method()
+#define SSL_SERVER_METH TLS_server_method()
+#define SSL_CLIENT_METH TLS_client_method()
 #define DESTROY_TIMEOUT 10
 
 pthread_mutex_t canl_lock = PTHREAD_MUTEX_INITIALIZER;
@@ -48,6 +48,7 @@ static canl_err_code
 ssl_initialize(glb_ctx *cc)
 {
     static pthread_once_t openssl_once = PTHREAD_ONCE_INIT;
+    X509_STORE *store;
 
     mech_glb_ctx **m_glb_ctx = (mech_glb_ctx **) &cc->mech_ctx;
     int err = 0;
@@ -106,7 +107,8 @@ ssl_initialize(glb_ctx *cc)
         goto end;
     }
     /* XXX: should be only defined on the SSL level: */
-    SSL_CTX_set_cert_verify_callback(ssl_ctx, proxy_app_verify_callback, 0);
+    store = SSL_CTX_get_cert_store(ssl_ctx);
+    X509_STORE_set_check_issued(store, proxy_check_issued);
 
     (*m_glb_ctx)->mech_ctx = ssl_ctx;
     ssl_ctx = NULL;
@@ -261,6 +263,7 @@ ssl_client_init(glb_ctx *cc, void **ctx)
     mech_glb_ctx *m_ctx = (mech_glb_ctx *)cc->mech_ctx;
     SSL_CTX *ssl_ctx = NULL;
     SSL *ssl = NULL;
+    X509_STORE *cert_store;
     int err = 0, i = 0;
     char *user_cert_fn, *user_key_fn, *user_proxy_fn;
     user_cert_fn = user_key_fn = user_proxy_fn = NULL;
@@ -272,6 +275,7 @@ ssl_client_init(glb_ctx *cc, void **ctx)
 	return set_error(cc, EINVAL, POSIX_ERROR, "SSL context not"
                 " initialized");
     ssl_ctx = (SSL_CTX *) m_ctx->mech_ctx;
+    cert_store = SSL_CTX_get_cert_store(ssl_ctx);
 
     err = proxy_get_filenames(0, NULL, NULL, &user_proxy_fn,
             &user_cert_fn, &user_key_fn);
@@ -322,11 +326,11 @@ ssl_client_init(glb_ctx *cc, void **ctx)
          * Certificate was a proxy with a cert. chain.
          * Add the certificates one by one to the chain.
          */
-        X509_STORE_add_cert(ssl_ctx->cert_store, m_ctx->cert_key->cert);
+        X509_STORE_add_cert(cert_store, m_ctx->cert_key->cert);
         for (i = 0; i < sk_X509_num(m_ctx->cert_key->chain); ++i) {
             X509 *cert = (sk_X509_value(m_ctx->cert_key->chain, i));
 
-            if (!X509_STORE_add_cert(ssl_ctx->cert_store, cert)) {
+            if (!X509_STORE_add_cert(cert_store, cert)) {
                 if (ERR_GET_REASON(ERR_peek_error()) == 
                         X509_R_CERT_ALREADY_IN_HASH_TABLE) {
                     ERR_clear_error();
@@ -339,7 +343,7 @@ ssl_client_init(glb_ctx *cc, void **ctx)
             }
         }
 #if OPENSSL_VERSION_NUMBER >= 0x10000000L
-        X509_STORE_set_verify_cb(ssl_ctx->cert_store, proxy_verify_callback);
+        X509_STORE_set_verify_cb(cert_store, proxy_verify_callback);
 #endif
     }
 
@@ -1255,6 +1259,7 @@ canl_ssl_ctx_set_clb(canl_ctx cc, SSL_CTX *ssl_ctx, int ver_mode,
 {
     glb_ctx *glb_cc = (glb_ctx*) cc;
     int (*vc)(int, X509_STORE_CTX *) = NULL;
+    X509_STORE *store;
 
     vc = (verify_callback) ? verify_callback : proxy_verify_callback;
 
@@ -1266,7 +1271,8 @@ canl_ssl_ctx_set_clb(canl_ctx cc, SSL_CTX *ssl_ctx, int ver_mode,
     mech_glb_ctx *m_ctx = (mech_glb_ctx *)glb_cc->mech_ctx;
     
     setup_SSL_proxy_handler(glb_cc, ssl_ctx, m_ctx->ca_dir, 1);
-    SSL_CTX_set_cert_verify_callback(ssl_ctx, proxy_app_verify_callback, NULL);
+    store = SSL_CTX_get_cert_store(ssl_ctx);
+    X509_STORE_set_check_issued(store, proxy_check_issued);
 
     SSL_CTX_set_verify(ssl_ctx, ver_mode, vc);
 
